| Safe Haskell | None |
|---|---|
| Language | GHC2024 |
NanoUI.Frame.Window
Description
Floating window input: dragging by the title bar, edge and inner-east resizing, the resize cursor, and persisting window placement.
Synopsis
- contextMeasurers :: Context -> Measurers
- lookupWindowPos :: Context -> WidgetId -> IO (Maybe (Float, Float))
- lookupWindowSize :: Context -> WidgetId -> IO (Maybe (Float, Float))
- persistWindowPositions :: Context -> IO ()
- updateWindowDrag :: Context -> Input -> IO Bool
- updateWindowResize :: Context -> Input -> Float -> Float -> IO Bool
- data WindowResizeEdge
- windowResizeCursorKind :: Context -> Input -> IO (Maybe UiCursorKind)
Documentation
contextMeasurers :: Context -> Measurers Source #
How the context measures text and custom widgets, for the solve and for placing floating nodes after it.
persistWindowPositions :: Context -> IO () Source #
data WindowResizeEdge Source #
Instances
| Eq WindowResizeEdge Source # | |
Defined in NanoUI.Context.Types Methods (==) :: WindowResizeEdge -> WindowResizeEdge -> Bool # (/=) :: WindowResizeEdge -> WindowResizeEdge -> Bool # | |
| Show WindowResizeEdge Source # | |
Defined in NanoUI.Context.Types Methods showsPrec :: Int -> WindowResizeEdge -> ShowS # show :: WindowResizeEdge -> String # showList :: [WindowResizeEdge] -> ShowS # | |
windowResizeCursorKind :: Context -> Input -> IO (Maybe UiCursorKind) Source #